height property

double? height
final

Default height is 0.

Some height of button is taken from padding, to completely erase height use height and padding zero.

Implementation

final double? height;